import React from 'react'

import styles from './todoSidebar.module.css'

export default function Todos({
  card,
  userId,
  categories,
  columns,
  voteOn,
  namedGroups,
}) {
  const {
    name,
    description,
    category,
    points,
    votes,
    id,
    group,
    gitlink,
  } = card
  const voteable = columns[card.state].clickable

  // TODO: hide vote button if not voteable
  return (
    <div className={styles.container}>
      <div className={styles.name}>
        <span className={styles.id}>#{id}</span>
        {name}
        <span
          style={{
            margin: '0px 5px',
            fontSize: '10px',
            backgroundColor: categories[category].color,
            color: 'white',
            borderRadius: '2px',
            padding: '0px 2px',
            whiteSpace: 'nowrap',
          }}
        >
          {categories[category].name}
        </span>
      </div>
      <hr />
      {group && (
        <div className={styles.row}>
          <div>Csoport:</div>
          <div style={{ color: group }}>
            {namedGroups[group] ? namedGroups[group].name : group}
          </div>
        </div>
      )}
      <div className={styles.row} title={'Minél több a pont, annál nehezebb'}>
        <div>Nehézség:</div>
        <div>{points}</div>
      </div>
      <div
        className={`${styles.row} ${votes.includes(userId) &&
          styles.votedtext}`}
        title={'Hány felhasználó szavazott a feladatra'}
      >
        <div>Szavazatok:</div>
        <div>{votes.length}</div>
      </div>
      {gitlink && (
        <div className={styles.row}>
          <a href={gitlink} target={'_blank'} rel={'noreferrer'}>
            Git link
          </a>
        </div>
      )}
      <hr />
      {description && (
        <>
          <div className={styles.title}>Leírás</div>
          <div dangerouslySetInnerHTML={{ __html: description }} />
          <hr />
        </>
      )}
      <div className={styles.category}></div>
      {voteable && (
        <div
          className={`${styles.button} ${votes.includes(userId) &&
            styles.voted}`}
          onClick={() => {
            voteOn(card)
          }}
        >
          {votes.includes(userId) ? 'Szavazat visszavonása' : 'Szavazás'}
        </div>
      )}
    </div>
  )
}
